@@ -1,6 +1,6 @@
 from PyQt5.QtWidgets import QWidget, QVBoxLayout, QDialog
-from transphire import tabdocker
 
+from . import tabdocker
 
 class LogViewerDialog(QDialog):
 
@@ -28,3 +28,4 @@ class LogViewerDialog(QDialog):
 
     def add_tab(self, widget, name):
         self.tabs.add_tab(widget, name)
+
