@@ -21,10 +21,11 @@ import sys
 from PyQt5.QtWidgets import QWidget, QLabel, QFileDialog, QVBoxLayout, QComboBox, QLineEdit, QHBoxLayout, QPushButton, QAction, QStyle
 from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt
 from PyQt5.QtGui import QKeySequence
-from transphire import transphire_utils as tu
-from transphire import inputbox
 import subprocess
 
+from . import transphire_utils as tu
+from . import inputbox
+
 
 class SettingsWidget(QWidget):
     """
